# RobotGPT Python bindings.
# 张圣涛 blaze.zhang
from urllib.parse import quote_plus

import robotgpt
from robotgpt import error, util
from robotgpt.robotgpt_object import RobotGPTObject
from typing import Optional

from robotgpt import api_requestor


class APIResource(RobotGPTObject):

    @classmethod
    def retrieve(
        cls, id, api_token=None, request_id=None, request_timeout=None, **params
    ):
        instance = cls(id=id, api_token=api_token, **params)
        instance.refresh(request_id=request_id, request_timeout=request_timeout)
        return instance

    @classmethod
    def aretrieve(
        cls, id, api_token=None, request_id=None, request_timeout=None, **params
    ):
        instance = cls(id=id, api_token=api_token, **params)
        return instance.arefresh(request_id=request_id, request_timeout=request_timeout)

    def refresh(self, request_id=None, request_timeout=None):
        self.refresh_from(
            self.request(
                "get",
                self.instance_url(),
                request_id=request_id,
                request_timeout=request_timeout,
            )
        )
        return self

    async def arefresh(self, request_id=None, request_timeout=None):
        self.refresh_from(
            await self.arequest(
                "get",
                self.instance_url(operation="refresh"),
                request_id=request_id,
                request_timeout=request_timeout,
            )
        )
        return self

    # The `method_` and `url_` arguments are suffixed with an underscore to
    # avoid conflicting with actual request parameters in `params`.
    @classmethod
    def _static_request(
        cls,
        method_,
        api_token=None,
        api_url=None,
        request_id=None,
        model=None,
        **params,
    ):
        requestor = api_requestor.APIRequestor(
            api_token,
            api_base=api_url,
            model=model,
        )
        response, _, api_token = requestor.request(
            method_, params, request_id=request_id
        )
        return util.convert_to_openai_object(
            response, api_token
        )

    @classmethod
    async def _astatic_request(
        cls,
        method_,
        api_token=None,
        api_url=None,
        request_id=None,
        model=None,
        **params,
    ):
        requestor = api_requestor.APIRequestor(
            api_token,
            api_url=api_url,
            model=model,
        )
        response, _, api_token = await requestor.arequest(
            method_, params, request_id=request_id
        )
        return response




# RobotGPT Python bindings.
# 张圣涛 blaze.zhang
import os
from contextvars import ContextVar
from typing import Optional, TYPE_CHECKING
from robotgpt.chat_completion import ChatCompletion
from robotgpt.error import APIError, InvalidRequestError, RobotGPTError

if TYPE_CHECKING:
    from aiohttp import ClientSession

api_token = os.environ.get("ROBOTGPT_API_KEY")
api_url = os.environ.get("ROBOTGPT_API_URL", "https://dataai.harix.iamidata.com/llm/api/ask")
verify_ssl_certs = True  # No effect. Certificates are always verified.
app_info = None
enable_telemetry = False  # Ignored; the telemetry feature was removed.
ca_bundle_path = None  # No longer used, feature was removed
debug = False
log = None  # Set to either 'debug' or 'info', controls console logging

aiosession: ContextVar[Optional["ClientSession"]] = ContextVar(
    "aiohttp-session", default=None
)  # Acts as a global aiohttp ClientSession that reuses connections.
# This is user-supplied; otherwise, a session is remade for each request.

__all__ = [
    "APIError",
    # "Audio",
    "ChatCompletion",
    # "Completion",
    # "Customer",
    # "Edit",
    # "Image",
    # "Deployment",
    # "Embedding",
    # "Engine",
    # "ErrorObject",
    # "File",
    # "FineTune",
    "InvalidRequestError",
    # "Model",
    # "Moderation",
    "RobotGPTError",
    "api_url",
    "api_token",
    "app_info",
    "ca_bundle_path",
    "debug",
    "enable_telemetry",
    "log",
    "verify_ssl_certs",
]



# RobotGPT Python bindings.
# 张圣涛 blaze.zhang
import logging
import os
import re
import sys
from enum import Enum
from typing import Optional
from robotgpt.robotgpt_object import RobotGPTObject
from robotgpt.robotgpt_response import RobotGPTResponse
import robotgpt

ROBOTGPT_LOG = os.environ.get("ROBOTGPT_LOG")

logger = logging.getLogger("robotgpt")

__all__ = [
    "log_info",
    "log_debug",
    "log_warn",
    "logfmt",
]

api_token_to_header = (
    lambda token: {"Authorization": f"{token}"}
)



def _console_log_level():
    if robotgpt.log in ["debug", "info"]:
        return robotgpt.log
    elif ROBOTGPT_LOG in ["debug", "info"]:
        return ROBOTGPT_LOG
    else:
        return None


def log_debug(message, **params):
    msg = logfmt(dict(message=message, **params))
    if _console_log_level() == "debug":
        print(msg, file=sys.stderr)
    logger.debug(msg)


def log_info(message, **params):
    msg = logfmt(dict(message=message, **params))
    if _console_log_level() in ["debug", "info"]:
        print(msg, file=sys.stderr)
    logger.info(msg)


def log_warn(message, **params):
    msg = logfmt(dict(message=message, **params))
    print(msg, file=sys.stderr)
    logger.warn(msg)


def logfmt(props):
    def fmt(key, val):
        # Handle case where val is a bytes or bytesarray
        if hasattr(val, "decode"):
            val = val.decode("utf-8")
        # Check if val is already a string to avoid re-encoding into ascii.
        if not isinstance(val, str):
            val = str(val)
        if re.search(r"\s", val):
            val = repr(val)
        # key should already be a string
        if re.search(r"\s", key):
            key = repr(key)
        return "{key}={val}".format(key=key, val=val)

    return " ".join([fmt(key, val) for key, val in sorted(props.items())])


def get_object_classes():
    # This is here to avoid a circular dependency
    from openai.object_classes import OBJECT_CLASSES

    return OBJECT_CLASSES


def convert_to_openai_object(
    resp,
    api_token=None,
    plain_old_data=False,
):
    # If we get a OpenAIResponse, we'll want to return a OpenAIObject.

    response_ms: Optional[int] = None
    if isinstance(resp, RobotGPTResponse):
        response_ms = resp.response_ms
        resp = resp.data

    if plain_old_data:
        return resp
    elif isinstance(resp, list):
        return [
            convert_to_openai_object(
                i, api_token
            )
            for i in resp
        ]
    elif isinstance(resp, dict) and not isinstance(
        resp, RobotGPTObject
    ):
        resp = resp.copy()
        klass_name = resp.get("object")
        if isinstance(klass_name, str):
            klass = get_object_classes().get(
                klass_name, RobotGPTObject
            )
        else:
            klass = RobotGPTObject

        return klass.construct_from(
            resp,
            api_token=api_token,
            response_ms=response_ms,
        )
    else:
        return resp


def convert_to_dict(obj):
    """Converts a OpenAIObject back to a regular dict.

    Nested OpenAIObjects are also converted back to regular dicts.

    :param obj: The OpenAIObject to convert.

    :returns: The OpenAIObject as a dict.
    """
    if isinstance(obj, list):
        return [convert_to_dict(i) for i in obj]
    # This works by virtue of the fact that OpenAIObjects _are_ dicts. The dict
    # comprehension returns a regular dict and recursively applies the
    # conversion to each value.
    elif isinstance(obj, dict):
        return {k: convert_to_dict(v) for k, v in obj.items()}
    else:
        return obj


def merge_dicts(x, y):
    z = x.copy()
    z.update(y)
    return z


def default_api_token() -> str:
    if robotgpt.api_token is not None:
        return robotgpt.api_token
    else:
        raise robotgpt.error.AuthenticationError(
            "No API token provided. You can set your API token in code using 'robotgpt.api_token = <API-TOKEN>', or you can set the environment variable OPENAI_API_TOKEN=<API-TOKEN>).You can generate API TOKEN in the ROBOTGPT web interface. See https://dataai-doc.dataarobotics.com/docs/getting-started/authentication for details."
        )



#!/usr/bin/env python
# coding: utf-8
import setuptools
from setuptools import setup

setup(
    name='robotgpt',
    version='0.0.3',
    author='blaze.zhang',
    author_email='blaze.zhang@cloudminds.com',
    url='https://src.cloudminds.com/ai-api/robotgptllm',
    description=u'RobotGPT LLM 支持Langchain',
    packages=['robotgpt'],
    install_requires=['langchain'],
)


# RobotGPT Python bindings.
# 张圣涛 blaze.zhang
import time
from pydoc import apropos
from typing import Optional
from urllib.parse import quote_plus

import robotgpt
from robotgpt import error, util
from robotgpt.robotgpt_response import RobotGPTResponse

from robotgpt import api_requestor
from robotgpt.api_resource import APIResource

MAX_TIMEOUT = 20


class EngineAPIResource(APIResource):
    plain_old_data = False

    def __init__(self, engine: Optional[str] = None, **kwargs):
        super().__init__(engine=engine, **kwargs)


    @classmethod
    def __prepare_create_request(
        cls,
        api_token=None,
        api_url=None,
        **params,
    ):
        model = params.get("model", None)
        timeout = params.pop("timeout", None)
        stream = params.get("stream", False)
        headers = params.pop("headers", None)
        request_timeout = params.pop("request_timeout", None)

        if timeout is None:
            # No special timeout handling
            pass
        elif timeout > 0:
            # API only supports timeouts up to MAX_TIMEOUT
            params["timeout"] = min(timeout, MAX_TIMEOUT)
            timeout = (timeout - params["timeout"]) or None
        elif timeout == 0:
            params["timeout"] = MAX_TIMEOUT

        requestor = api_requestor.APIRequestor(
            api_token,
            api_url=api_url,
            model=model
        )
        return (
            timeout,
            stream,
            headers,
            request_timeout,
            requestor,
            api_url,
            params,
        )

    @classmethod
    def create(
        cls,
        api_token=None,
        api_url=None,
        request_id=None,
        **params,
    ):
        (
            timeout,
            stream,
            headers,
            request_timeout,
            requestor,
            url,
            params,
        ) = cls.__prepare_create_request(
            api_token, api_url, **params
        )

        response, _, api_token = requestor.request(
            "post",
            params=params,
            headers=headers,
            stream=stream,
            request_id=request_id,
            request_timeout=request_timeout,
        )

        if stream:
            # must be an iterator
            assert not isinstance(response, RobotGPTResponse)
            return (
                util.convert_to_openai_object(
                    line,
                    api_token,
                    plain_old_data=cls.plain_old_data,
                )
                for line in response
            )
        else:
            obj = util.convert_to_openai_object(
                response,
                api_token,
                plain_old_data=cls.plain_old_data,
            )

            if timeout is not None:
                obj.wait(timeout=timeout or None)

        return obj

    @classmethod
    async def acreate(
        cls,
        api_token=None,
        api_url=None,
        request_id=None,
        **params,
    ):
        (
            timeout,
            stream,
            headers,
            request_timeout,
            requestor,
            url,
            params,
        ) = cls.__prepare_create_request(
            api_token, api_url, **params
        )
        response, _, api_token = await requestor.arequest(
            "post",
            url,
            params=params,
            headers=headers,
            stream=stream,
            request_id=request_id,
            request_timeout=request_timeout,
        )

        if stream:
            # must be an iterator
            assert not isinstance(response, RobotGPTResponse)
            return (
                util.convert_to_openai_object(
                    line,
                    api_url,
                    plain_old_data=cls.plain_old_data,
                )
                async for line in response
            )
        else:
            obj = util.convert_to_openai_object(
                response,
                api_token,
                plain_old_data=cls.plain_old_data,
            )

            if timeout is not None:
                await obj.await_(timeout=timeout or None)

        return obj

    def wait(self, timeout=None):
        start = time.time()
        while self.status != "complete":
            self.timeout = (
                min(timeout + start - time.time(), MAX_TIMEOUT)
                if timeout is not None
                else MAX_TIMEOUT
            )
            if self.timeout < 0:
                del self.timeout
                break
            self.refresh()
        return self

    async def await_(self, timeout=None):
        """Async version of `EngineApiResource.wait`"""
        start = time.time()
        while self.status != "complete":
            self.timeout = (
                min(timeout + start - time.time(), MAX_TIMEOUT)
                if timeout is not None
                else MAX_TIMEOUT
            )
            if self.timeout < 0:
                del self.timeout
                break
            await self.arefresh()
        return self
